;##########################################################################
; This script will create a "flakeinput_d01.nc" file given:
; 1. a wrfinput_d01.nc file 
; 2. a restart or an output from an offline flake run (ex. "restartSimul2001d01.nc") 
;    or from a wrf simulation (ex. "wrfflake_d01_1999-01-01_00:00:00") 
;
; 
;  Jonathan Gula, UCLA (E-mail: gula@atmos.ucla.edu )
;##########################################################################

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

;##########################################################################
undef("CopyAtt")
procedure CopyAtt( a , b )

local yo, i
begin
		yo = getvaratts(b)

		do i = 0,dimsizes(yo)-1
			a@$yo(i)$ = b@$yo(i)$
		end do
end
;##########################################################################

begin

;##########################################################################

    ;INPUT
    wrf = addfile("wrfinput_d01.nc", "r")
    flake = addfile("wrfflake_d01_1999-01-01_00:00:00.nc", "r")

    ;OUTPUT
    flakeinputname="flakeinput_d01.nc"
    system ("rm "+flakeinputname)
    flakeinput = addfile(flakeinputname, "c")

     ;##########################################################################

    if isfilevar(flake, "T_SNOW_LAKE") then
	    namesin    = (/"T_SNOW_LAKE", "T_ICE_LAKE", "T_MNW_LAKE", "T_WML_LAKE", "T_BOT_LAKE", "T_B1_LAKE", "C_T_LAKE", "H_SNOW_LAKE", "H_ICE_LAKE", "H_ML_LAKE", "H_B1_LAKE", "T_SFC_LAKE"/)
    else

	    namesin    =(/"T_snow" ,"T_ice","T_mnw" ,"T_wML","T_bot" ,"T_B1","C_T" ,"h_snow","h_ice" ,"h_ML" ,"H_B1" ,"T_sfc"/)
    end if

    namesout    = (/"T_SNOW_LAKE", "T_ICE_LAKE", "T_MNW_LAKE", "T_WML_LAKE", "T_BOT_LAKE", "T_B1_LAKE", "C_T_LAKE", "H_SNOW_LAKE", "H_ICE_LAKE", "H_ML_LAKE", "H_B1_LAKE", "T_SFC_LAKE"/)


     ;##########################################################################

    LAKE_DEPTH = wrf->LAKE_DEPTH	

    ntimes=dimsizes(flake->$namesin(0)$)

    ;##########################################################################
    ;Which time step in the flake file (default = uses the last time index)
    ;##########################################################################
    timeflake = ntimes(0)-1


    do i = 0, dimsizes(namesin)-1  

	    var=LAKE_DEPTH

	    var(0,:,:) = flake->$namesin(i)$(timeflake,:,:)
	    var = where(LAKE_DEPTH.gt.0,var,0)

	    var@FieldType = 104
	    var@MemoryOrder = "XY"
	    var@stagger = ""	
	    var@coordinates = "XLONG XLAT"

	    flakeinput->$namesout(i)$ = var

    end do   

    flakeinput->Times = wrf->Times
    flakeinput->XLONG = wrf->XLONG(0,:,:)
    flakeinput->XLAT = wrf->XLAT(0,:,:)

    CopyAtt( flakeinput , wrf )
end
